Package: biostat3
Type: Package
Title: Utility Functions, Datasets and Extended Examples for Survival
        Analysis
Version: 0.1.9
Date: 2023-10-27
Authors@R: c(person("Annika","Tillander", role="ctb"),
	  person("Andreas","Karlsson", role="aut"),
	  person("Johan","Zetterqvist", role="ctb"),
	  person("Peter","Strom", role="ctb"),
	  person("Benedicte","Delcoigne", role="ctb"),
	  person("Mark","Clements", role=c("aut","cre"), email="mark.clements@ki.se")
	  )
Description: Utility functions, datasets and extended examples for survival analysis. This extends a range of other packages, some simple wrappers for time-to-event analyses, datasets, and extensive examples in HTML with R scripts. The package also supports the course Biostatistics III entitled "Survival analysis for epidemiologists in R".
Depends: survival, R (>= 3.5), MASS, methods
Imports: muhaz, graphics, stats
Suggests: car, bshazard, rstpm2, Epi, dplyr
License: GPL (>= 2)
LazyData: yes
LazyLoad: yes
NeedsCompilation: no
Packaged: 2023-10-27 09:21:58 UTC; marcle
Author: Annika Tillander [ctb],
  Andreas Karlsson [aut],
  Johan Zetterqvist [ctb],
  Peter Strom [ctb],
  Benedicte Delcoigne [ctb],
  Mark Clements [aut, cre]
Maintainer: Mark Clements <mark.clements@ki.se>
Repository: CRAN
Date/Publication: 2023-10-27 10:10:06 UTC
Built: R 4.2.0; ; 2023-10-27 12:06:46 UTC; unix
