exportPattern("^[[:alpha:]]+") # export names that start with a letter 

import(survival)
import(methods)
import(MASS)
## importFrom(muhaz, muhaz, plot.muhaz, lines.muhaz)
## importFrom(car, linearHypothesis)
importFrom(graphics, lines, plot, matlines, matplot, plot.default,
           points)
importFrom(stats, model.extract, terms, qnorm, approx,
           profile, fitted, qt, spline, coef, confint,
           predict, qgamma)
importFrom("utils", "modifyList")

## importFrom(KMsurv,lifetab)
## importFrom(MASS, confint, profile)

S3method(as.data.frame,bshazard)
S3method(as.data.frame,muhaz)
S3method(as.data.frame,muhazList)
## S3method(confint,glm)
## S3method(confint, profile.glm)
S3method(eform,default)
S3method(lines,coxphHazList)
S3method(lines,muhaz2)
S3method(lines,muhazList)
S3method(plot,coxphHaz)
S3method(plot,coxphHazList)
S3method(as.data.frame,coxphHaz)
S3method(as.data.frame,coxphHazList)
S3method(plot,muhaz2)
S3method(plot,muhazList)
S3method(plot,smoothHaz)
S3method(print,coxphHaz)
S3method(summary,muhazList)
S3method(plot,lifetab2)
S3method(lines,lifetab2)
S3method(points,lifetab2)

## S3method(ggplot,muhazList)
