---
title: "Biostatistics III in R"
author:
- Code by Mark Clements
output:
  prettydoc::html_pretty:
    mathjax: https://biostat3.net/js/mathjax/tex-chtml.js
    theme: cayman
    highlight: github
---

# Exercise 23. Calculating SMRs/SIRs #

-----------

```{r setup, cache=FALSE, message=FALSE, echo=FALSE}
library('knitr')
read_chunk('../q23.R')
opts_chunk$set(cache=FALSE)
```

```{r loadDependencies, message=FALSE}
```

```{r loadPreprocess, results='hide'}
```


## (a) ##

```{r 23.a1}
```

```{r 23.a2}
```

## (b) ##

```{r 23.b1}
```

```{r 23.b2}
```

## (c) ##


```{r 23.c1}
```

```{r 23.c2}
```

```{r 23.c3}
```

## (d) ##


```{r 23.d}
```

## (e) ##

		
```{r 23.e1}
```

```{r 23.e2}
```

```{r 23.e3}
```

```{r 23.e4}
```

## (f) ##


```{r 23.f1, results='asis'}
```

```{r 23.f2, results='asis'}
```

```{r 23.f3, results='asis'}
```

```{r 23.f4, results='asis'}
```

```{r 23.f5}
```

## (g) ##

```{r 23.g1}
```

```{r 23.g2}
```

