---
title: "Biostatistics III in R"
author:
- Code by Johan Zetterqvist and Mark Clements
output:
  prettydoc::html_pretty:
    theme: cayman
    highlight: github
---

# Exercise 11. Cox regression with all-cause mortality as the outcome #


Now fit a model to the localised melanoma data where the outcome is observed survival (i.e. all deaths are considered to be events).

```{r setup, cache=FALSE, message=FALSE, echo=FALSE}
library('knitr')
read_chunk('../q11.R')
opts_chunk$set(cache=FALSE)
```

You may have to install the required packages the first time you use them. You can install a package by `install.packages("package_of_interest")` for each package you require.

```{r loadDependencies, message=FALSE}
```
Load the melanoma data and explore it.

```{r loadPreprocess, results='hide', eval=FALSE}
```

## (a) ## 

Interpret the estimated hazard ratio for the parameter labelled `agegrp60-74`, including a comment on statistical significance.


```{r 11.a, warning=FALSE, results='hide', eval=FALSE}
```

Write out the regression equation. Using the regression equation, write out a formula for the hazard ratio for a male aged 60--74 years compared with a female aged 75 years or over.

## (b) ## 

On comparing the estimates between the observed and cause-specific survival models it appears that only the parameters for age have changed substantially. Can you explain why the estimates for the effect of age would be expected to change more than the estimates of the effect of sex and period?

```{r 11.b, warning=FALSE, results='hide', eval=FALSE}
```
