---
title: "Biostatistics III in R"
author:
- Andreas Karlsson and Mark Clements
output:
  html_document:
    theme: null
  html_vignette: default
  prettydoc::html_pretty: default
---

Installation for Biostatistics III in R
======================================================

R will be used throughout the course. This section describes how to
download and install the files required for the computing exercises
(e.g., data files) as well as how to install packages for
extending R. If you are working in a computer lab during a course
it’s possible these files may have already been installed for you.

Download and installation of R packages is generally done within R. The packages can be installed from CRAN by

    install.packages("biostat3")
    install.packages(c("bshazard","rstpm2","Epi","dplyr"))

You can use the `library` function to check if an R package is installed (and load it).

    library(biostat3)  # main package
	## some additional packages
    library(rstpm2)    # stpm2(), pstpm2()
    library(bshazard)  # bshazard()
    library(Epi)       # ccwc()
    library(dplyr)     # mutate(), filter(), group_by(), summarise(), %>%
	
You can also read the data files directly from the web from within
R. For example,

    library(foreign)
	colon <- read.dta("http://www.biostat3.net/download/colon.dta")
