---
title: "WebR-enabled code cell"
format: html
engine: knitr
#webr:
#  show-startup-message: false    # Disable display of webR initialization state
#  show-header-message: true      # Display whether COOP&COEP headers are set for speed.
#  packages: ['ggplot2', 'dplyr'] # Pre-install dependencies
#  autoload-packages: false       # Disable automatic library calls on R packages specified in packages.
#  repos:                         # Specify repositories to check for custom packages
#    - https://github-username.github.io/reponame
#    - https://username.r-universe.dev
#  channel-type: 'post-message'   # Specify a specific communication channel type.
#  home-dir: "/home/rstudio"      # Customize where the working directory is
#  base-url: ''                   # Base URL used for downloading R WebAssembly binaries
#  service-worker-url: ''         # URL from where to load JavaScript worker scripts when loading webR with the ServiceWorker communication channel.
filters:
- webr
---

## Demo

This is a webr-enabled code cell in a Quarto HTML document.

```{webr-r}
1 + 1 
```

```{webr-r}
fit = lm(mpg ~ am, data = mtcars)
summary(fit)
```

```{webr-r}
plot(pressure)
```
